.. image:: https://github.com/ihmeuw-msca/lme-for-forecast/workflows/build/badge.svg
    :target: https://github.com/ihmeuw-msca/lme-for-forecast/actions

LimeTr Wrapper for Forecast Team
================================

To install the package, you will need to install `cyipopt <https://cyipopt.readthedocs.io/en/stable/>`_ first and then install "flme" through pip.

.. code-block:: bash

   conda install -c conda-forge cyipopt -y
   pip install flme

